/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type tanhf_vec[] = {
{31, 0,123,__LINE__, 0xbfeaad4c, 0x74f7d74d, 0xbff33333, 0x33333333},	/* -0.833655=f(-1.2)*/
{31, 0,123,__LINE__, 0xbfea941a, 0x2c2aec65, 0xbff30a3d, 0x70a3d70a},	/* -0.830579=f(-1.19)*/
{31, 0,123,__LINE__, 0xbfea7a7b, 0xc428869f, 0xbff2e147, 0xae147ae1},	/* -0.827452=f(-1.18)*/
{31, 0,123,__LINE__, 0xbfea6070, 0x0070fc32, 0xbff2b851, 0xeb851eb8},	/* -0.824272=f(-1.17)*/
{31, 0,123,__LINE__, 0xbfea45f5, 0x680a1f66, 0xbff28f5c, 0x28f5c28f},	/* -0.82104=f(-1.16)*/
{31, 0,123,__LINE__, 0xbfea2b0a, 0x956429fb, 0xbff26666, 0x66666666},	/* -0.817754=f(-1.15)*/
{31, 0,123,__LINE__, 0xbfea0fae, 0x22adf735, 0xbff23d70, 0xa3d70a3d},	/* -0.814414=f(-1.14)*/
{31, 0,123,__LINE__, 0xbfe9f3de, 0xaa045182, 0xbff2147a, 0xe147ae14},	/* -0.811019=f(-1.13)*/
{31, 0,123,__LINE__, 0xbfe9d79a, 0xc5a3097f, 0xbff1eb85, 0x1eb851eb},	/* -0.807569=f(-1.12)*/
{31, 0,123,__LINE__, 0xbfe9bae1, 0x1017dbf4, 0xbff1c28f, 0x5c28f5c2},	/* -0.804062=f(-1.11)*/
{31, 0,123,__LINE__, 0xbfe99db0, 0x24772beb, 0xbff19999, 0x99999999},	/* -0.800499=f(-1.1)*/
{31, 0,123,__LINE__, 0xbfe98006, 0x9e929588, 0xbff170a3, 0xd70a3d70},	/* -0.796878=f(-1.09)*/
{31, 0,123,__LINE__, 0xbfe961e3, 0x1b315dd8, 0xbff147ae, 0x147ae147},	/* -0.793199=f(-1.08)*/
{31, 0,123,__LINE__, 0xbfe94344, 0x384ac334, 0xbff11eb8, 0x51eb851e},	/* -0.789461=f(-1.07)*/
{31, 0,123,__LINE__, 0xbfe92428, 0x7cc381b4, 0xbff0f5c2, 0x8f5c28f5},	/* -0.785664=f(-1.06)*/
{31, 0,123,__LINE__, 0xbfe9048e, 0xba439aea, 0xbff0cccc, 0xcccccccc},	/* -0.781806=f(-1.05)*/
{31, 0,123,__LINE__, 0xbfe8e475, 0x7ba65d2e, 0xbff0a3d7, 0x0a3d70a3},	/* -0.777888=f(-1.04)*/
{31, 0,123,__LINE__, 0xbfe8c3db, 0x660ffc0e, 0xbff07ae1, 0x47ae147a},	/* -0.773908=f(-1.03)*/
{31, 0,123,__LINE__, 0xbfe8a2bf, 0x2114b4c9, 0xbff051eb, 0x851eb851},	/* -0.769867=f(-1.02)*/
{31, 0,123,__LINE__, 0xbfe8811f, 0x56fe8c0b, 0xbff028f5, 0xc28f5c28},	/* -0.765762=f(-1.01)*/
{31, 0,123,__LINE__, 0xbfe85efa, 0xb514f394, 0xbfefffff, 0xfffffffe},	/* -0.761594=f(-1)*/
{31, 0,123,__LINE__, 0xbfe83c4f, 0xebe655c0, 0xbfefae14, 0x7ae147ac},	/* -0.757362=f(-0.99)*/
{31, 0,123,__LINE__, 0xbfe8191d, 0xaf938402, 0xbfef5c28, 0xf5c28f5a},	/* -0.753066=f(-0.98)*/
{31, 0,123,__LINE__, 0xbfe7f562, 0xb81d047d, 0xbfef0a3d, 0x70a3d708},	/* -0.748704=f(-0.97)*/
{31, 0,123,__LINE__, 0xbfe7d11d, 0xb36c2b33, 0xbfeeb851, 0xeb851eb6},	/* -0.744277=f(-0.96)*/
{31, 0,123,__LINE__, 0xbfe7ac4d, 0x7e85af15, 0xbfee6666, 0x66666664},	/* -0.739783=f(-0.95)*/
{31, 0,123,__LINE__, 0xbfe786f0, 0xd0db87fb, 0xbfee147a, 0xe147ae12},	/* -0.735222=f(-0.94)*/
{31, 0,123,__LINE__, 0xbfe76106, 0x7516c86a, 0xbfedc28f, 0x5c28f5c0},	/* -0.730594=f(-0.93)*/
{31, 0,123,__LINE__, 0xbfe73a8d, 0x3b5e00f0, 0xbfed70a3, 0xd70a3d6e},	/* -0.725897=f(-0.92)*/
{31, 0,123,__LINE__, 0xbfe71383, 0xf9ad3df6, 0xbfed1eb8, 0x51eb851c},	/* -0.721132=f(-0.91)*/
{31, 0,123,__LINE__, 0xbfe6ebe9, 0x7c9ad878, 0xbfeccccc, 0xccccccca},	/* -0.716298=f(-0.9)*/
{31, 0,123,__LINE__, 0xbfe6c3bc, 0xc5cca797, 0xbfec7ae1, 0x47ae1478},	/* -0.711394=f(-0.89)*/
{31, 0,123,__LINE__, 0xbfe69afc, 0xaf837b0b, 0xbfec28f5, 0xc28f5c26},	/* -0.706419=f(-0.88)*/
{31, 0,123,__LINE__, 0xbfe671a8, 0x2aa1777d, 0xbfebd70a, 0x3d70a3d4},	/* -0.701374=f(-0.87)*/
{31, 0,123,__LINE__, 0xbfe647be, 0x2fade1c2, 0xbfeb851e, 0xb851eb82},	/* -0.696258=f(-0.86)*/
{31, 0,123,__LINE__, 0xbfe61d3d, 0xbf3629d9, 0xbfeb3333, 0x33333330},	/* -0.691069=f(-0.85)*/
{31, 0,123,__LINE__, 0xbfe5f225, 0xd13d35cf, 0xbfeae147, 0xae147ade},	/* -0.685809=f(-0.84)*/
{31, 0,123,__LINE__, 0xbfe5c675, 0x992f4a62, 0xbfea8f5c, 0x28f5c28c},	/* -0.680476=f(-0.83)*/
{31, 0,123,__LINE__, 0xbfe59a2c, 0x21473e1c, 0xbfea3d70, 0xa3d70a3a},	/* -0.67507=f(-0.82)*/
{31, 0,123,__LINE__, 0xbfe56d48, 0x8e0dd01d, 0xbfe9eb85, 0x1eb851e8},	/* -0.66959=f(-0.81)*/
{31, 0,123,__LINE__, 0xbfe53fca, 0x0e087efc, 0xbfe99999, 0x99999996},	/* -0.664037=f(-0.8)*/
{31, 0,123,__LINE__, 0xbfe511af, 0xda20de09, 0xbfe947ae, 0x147ae144},	/* -0.658409=f(-0.79)*/
{31, 0,123,__LINE__, 0xbfe4e2f9, 0x23ae9d67, 0xbfe8f5c2, 0x8f5c28f2},	/* -0.652707=f(-0.78)*/
{31, 0,123,__LINE__, 0xbfe4b3a5, 0x5e1a9c8e, 0xbfe8a3d7, 0x0a3d70a0},	/* -0.646929=f(-0.77)*/
{31, 0,123,__LINE__, 0xbfe483b3, 0xd1cc4882, 0xbfe851eb, 0x851eb84e},	/* -0.641077=f(-0.76)*/
{31, 0,123,__LINE__, 0xbfe45323, 0xe552f228, 0xbfe7ffff, 0xfffffffc},	/* -0.635149=f(-0.75)*/
{31, 0,123,__LINE__, 0xbfe421f5, 0x0bae9fa4, 0xbfe7ae14, 0x7ae147aa},	/* -0.629145=f(-0.74)*/
{31, 0,123,__LINE__, 0xbfe3f026, 0xc4b9a929, 0xbfe75c28, 0xf5c28f58},	/* -0.623065=f(-0.73)*/
{31, 0,123,__LINE__, 0xbfe3bdb8, 0x9d923c1f, 0xbfe70a3d, 0x70a3d706},	/* -0.616909=f(-0.72)*/
{31, 0,123,__LINE__, 0xbfe38aaa, 0x1cf2a06c, 0xbfe6b851, 0xeb851eb4},	/* -0.610677=f(-0.71)*/
{31, 0,123,__LINE__, 0xbfe356fb, 0x139f397c, 0xbfe66666, 0x66666662},	/* -0.604368=f(-0.7)*/
{31, 0,123,__LINE__, 0xbfe322ab, 0x252528fc, 0xbfe6147a, 0xe147ae10},	/* -0.597982=f(-0.69)*/
{31, 0,123,__LINE__, 0xbfe2edba, 0x17c99e36, 0xbfe5c28f, 0x5c28f5be},	/* -0.591519=f(-0.68)*/
{31, 0,123,__LINE__, 0xbfe2b827, 0xc11e21e8, 0xbfe570a3, 0xd70a3d6c},	/* -0.58498=f(-0.67)*/
{31, 0,123,__LINE__, 0xbfe281f4, 0x066618da, 0xbfe51eb8, 0x51eb851a},	/* -0.578363=f(-0.66)*/
{31, 0,123,__LINE__, 0xbfe24b1e, 0xc7703122, 0xbfe4cccc, 0xccccccc8},	/* -0.57167=f(-0.65)*/
{31, 0,123,__LINE__, 0xbfe213a8, 0x34e54dfe, 0xbfe47ae1, 0x47ae1476},	/* -0.5649=f(-0.64)*/
{31, 0,123,__LINE__, 0xbfe1db90, 0x5025fabc, 0xbfe428f5, 0xc28f5c24},	/* -0.558052=f(-0.63)*/
{31, 0,123,__LINE__, 0xbfe1a2d7, 0x4117ab46, 0xbfe3d70a, 0x3d70a3d2},	/* -0.551128=f(-0.62)*/
{31, 0,123,__LINE__, 0xbfe1697d, 0x413629fe, 0xbfe3851e, 0xb851eb80},	/* -0.544127=f(-0.61)*/
{31, 0,123,__LINE__, 0xbfe12f82, 0x9bee7fab, 0xbfe33333, 0x3333332e},	/* -0.53705=f(-0.6)*/
{31, 0,123,__LINE__, 0xbfe0f4e7, 0x97f39ce5, 0xbfe2e147, 0xae147adc},	/* -0.529896=f(-0.59)*/
{31, 0,123,__LINE__, 0xbfe0b9ac, 0xd364dc1d, 0xbfe28f5c, 0x28f5c28a},	/* -0.522665=f(-0.58)*/
{31, 0,123,__LINE__, 0xbfe07dd2, 0xbac5797e, 0xbfe23d70, 0xa3d70a38},	/* -0.515359=f(-0.57)*/
{31, 0,123,__LINE__, 0xbfe04159, 0xe4a0014b, 0xbfe1eb85, 0x1eb851e6},	/* -0.507977=f(-0.56)*/
{31, 0,123,__LINE__, 0xbfe00442, 0xfb0d8481, 0xbfe19999, 0x99999994},	/* -0.50052=f(-0.55)*/
{31, 0,123,__LINE__, 0xbfdf8d1d, 0x77fd0a49, 0xbfe147ae, 0x147ae142},	/* -0.492988=f(-0.54)*/
{31, 0,123,__LINE__, 0xbfdf107b, 0xc21445fd, 0xbfe0f5c2, 0x8f5c28f0},	/* -0.485381=f(-0.53)*/
{31, 0,123,__LINE__, 0xbfde92a3, 0x029587f5, 0xbfe0a3d7, 0x0a3d709e},	/* -0.4777=f(-0.52)*/
{31, 0,123,__LINE__, 0xbfde1394, 0xff1a989d, 0xbfe051eb, 0x851eb84c},	/* -0.469945=f(-0.51)*/
{31, 0,123,__LINE__, 0xbfdd9353, 0xd7568af3, 0xbfdfffff, 0xfffffff4},	/* -0.462117=f(-0.5)*/
{31, 0,123,__LINE__, 0xbfdd11e1, 0xd50bdfa6, 0xbfdf5c28, 0xf5c28f50},	/* -0.454216=f(-0.49)*/
{31, 0,123,__LINE__, 0xbfdc8f41, 0x52ca7782, 0xbfdeb851, 0xeb851eac},	/* -0.446244=f(-0.48)*/
{31, 0,123,__LINE__, 0xbfdc0b75, 0x228cc44a, 0xbfde147a, 0xe147ae08},	/* -0.438199=f(-0.47)*/
{31, 0,123,__LINE__, 0xbfdb867f, 0xf4ed5088, 0xbfdd70a3, 0xd70a3d64},	/* -0.430084=f(-0.46)*/
{31, 0,123,__LINE__, 0xbfdb0064, 0xa4eb581e, 0xbfdccccc, 0xccccccc0},	/* -0.421899=f(-0.45)*/
{31, 0,123,__LINE__, 0xbfda7926, 0x87b830fc, 0xbfdc28f5, 0xc28f5c1c},	/* -0.413644=f(-0.44)*/
{31, 0,123,__LINE__, 0xbfd9f0c8, 0xcfb771c0, 0xbfdb851e, 0xb851eb78},	/* -0.405321=f(-0.43)*/
{31, 0,123,__LINE__, 0xbfd9674e, 0xda335a52, 0xbfdae147, 0xae147ad4},	/* -0.39693=f(-0.42)*/
{31, 0,123,__LINE__, 0xbfd8dcbc, 0x80f8073c, 0xbfda3d70, 0xa3d70a30},	/* -0.388473=f(-0.41)*/
{31, 0,123,__LINE__, 0xbfd85115, 0x793c23c1, 0xbfd99999, 0x9999998c},	/* -0.379949=f(-0.4)*/
{31, 0,123,__LINE__, 0xbfd7c45d, 0xa3330f2c, 0xbfd8f5c2, 0x8f5c28e8},	/* -0.37136=f(-0.39)*/
{31, 0,123,__LINE__, 0xbfd73699, 0x5d5e8706, 0xbfd851eb, 0x851eb844},	/* -0.362707=f(-0.38)*/
{31, 0,123,__LINE__, 0xbfd6a7cc, 0xdf83afa8, 0xbfd7ae14, 0x7ae147a0},	/* -0.353992=f(-0.37)*/
{31, 0,123,__LINE__, 0xbfd617fc, 0xa8366b98, 0xbfd70a3d, 0x70a3d6fc},	/* -0.345214=f(-0.36)*/
{31, 0,123,__LINE__, 0xbfd5872d, 0x44d94d5c, 0xbfd66666, 0x66666658},	/* -0.336376=f(-0.35)*/
{31, 0,123,__LINE__, 0xbfd4f563, 0xc2a61bb5, 0xbfd5c28f, 0x5c28f5b4},	/* -0.327477=f(-0.34)*/
{31, 0,123,__LINE__, 0xbfd462a5, 0x049fff03, 0xbfd51eb8, 0x51eb8510},	/* -0.318521=f(-0.33)*/
{31, 0,123,__LINE__, 0xbfd3cef6, 0x172ddf0d, 0xbfd47ae1, 0x47ae146c},	/* -0.309507=f(-0.32)*/
{31, 0,123,__LINE__, 0xbfd33a5c, 0x87047be5, 0xbfd3d70a, 0x3d70a3c8},	/* -0.300437=f(-0.31)*/
{31, 0,123,__LINE__, 0xbfd2a4dd, 0xb38fcd80, 0xbfd33333, 0x33333324},	/* -0.291313=f(-0.3)*/
{31, 0,123,__LINE__, 0xbfd20e7f, 0x241f7d6f, 0xbfd28f5c, 0x28f5c280},	/* -0.282135=f(-0.29)*/
{31, 0,123,__LINE__, 0xbfd17746, 0xe02ada59, 0xbfd1eb85, 0x1eb851dc},	/* -0.272905=f(-0.28)*/
{31, 0,123,__LINE__, 0xbfd0df3a, 0xbe6937ae, 0xbfd147ae, 0x147ae138},	/* -0.263625=f(-0.27)*/
{31, 0,123,__LINE__, 0xbfd04660, 0xbb75a174, 0xbfd0a3d7, 0x0a3d7094},	/* -0.254296=f(-0.26)*/
{31, 0,123,__LINE__, 0xbfcf597e, 0xa69a1c86, 0xbfcfffff, 0xffffffe0},	/* -0.244919=f(-0.25)*/
{30, 0,123,__LINE__, 0xbfce24b9, 0x7c6d2273, 0xbfceb851, 0xeb851e98},	/* -0.235496=f(-0.24)*/
{31, 0,123,__LINE__, 0xbfccee7f, 0x47014c81, 0xbfcd70a3, 0xd70a3d50},	/* -0.226028=f(-0.23)*/
{31, 0,123,__LINE__, 0xbfcbb6dd, 0x221cea59, 0xbfcc28f5, 0xc28f5c08},	/* -0.216518=f(-0.22)*/
{31, 0,123,__LINE__, 0xbfca7de0, 0xc8603bef, 0xbfcae147, 0xae147ac0},	/* -0.206966=f(-0.21)*/
{31, 0,123,__LINE__, 0xbfc94398, 0x36da3834, 0xbfc99999, 0x99999978},	/* -0.197375=f(-0.2)*/
{31, 0,123,__LINE__, 0xbfc80811, 0x4e22fbfe, 0xbfc851eb, 0x851eb830},	/* -0.187746=f(-0.19)*/
{31, 0,123,__LINE__, 0xbfc6cb5a, 0xa72d2f46, 0xbfc70a3d, 0x70a3d6e8},	/* -0.178081=f(-0.18)*/
{31, 0,123,__LINE__, 0xbfc58d82, 0x9a5f30ea, 0xbfc5c28f, 0x5c28f5a0},	/* -0.168381=f(-0.17)*/
{31, 0,123,__LINE__, 0xbfc44e98, 0x15459720, 0xbfc47ae1, 0x47ae1458},	/* -0.158649=f(-0.16)*/
{31, 0,123,__LINE__, 0xbfc30eaa, 0x3ba77e4f, 0xbfc33333, 0x33333310},	/* -0.148885=f(-0.15)*/
{31, 0,123,__LINE__, 0xbfc1cdc8, 0x06a26fb7, 0xbfc1eb85, 0x1eb851c8},	/* -0.139092=f(-0.14)*/
{31, 0,123,__LINE__, 0xbfc08c00, 0xfd5c1efe, 0xbfc0a3d7, 0x0a3d7080},	/* -0.129273=f(-0.13)*/
{31, 0,123,__LINE__, 0xbfbe92c9, 0x8a196039, 0xbfbeb851, 0xeb851e71},	/* -0.119427=f(-0.12)*/
{31, 0,123,__LINE__, 0xbfbc0c06, 0x1c0a9f45, 0xbfbc28f5, 0xc28f5be2},	/* -0.109558=f(-0.11)*/
{31, 0,123,__LINE__, 0xbfb983d7, 0x7fb56120, 0xbfb99999, 0x99999953},	/* -0.099668=f(-0.1)*/
{31, 0,123,__LINE__, 0xbfb6fa5d, 0xcd496607, 0xbfb70a3d, 0x70a3d6c4},	/* -0.0897578=f(-0.09)*/
{31, 0,123,__LINE__, 0xbfb46fb9, 0x3ff2cfcc, 0xbfb47ae1, 0x47ae1435},	/* -0.0798298=f(-0.08)*/
{31, 0,123,__LINE__, 0xbfb1e40a, 0xaea278b0, 0xbfb1eb85, 0x1eb851a6},	/* -0.0698859=f(-0.07)*/
{31, 0,123,__LINE__, 0xbfaeaee5, 0x6e0f2f94, 0xbfaeb851, 0xeb851e2d},	/* -0.0599281=f(-0.06)*/
{31, 0,123,__LINE__, 0xbfa99424, 0xeb98468a, 0xbfa99999, 0x9999990e},	/* -0.0499584=f(-0.05)*/
{31, 0,123,__LINE__, 0xbfa47815, 0xe1479706, 0xbfa47ae1, 0x47ae13ef},	/* -0.0399787=f(-0.04)*/
{31, 0,123,__LINE__, 0xbf9eb5f6, 0x1cd488c9, 0xbf9eb851, 0xeb851da0},	/* -0.029991=f(-0.03)*/
{31, 0,123,__LINE__, 0xbf947a2e, 0x5258f3e4, 0xbf947ae1, 0x47ae1362},	/* -0.0199973=f(-0.02)*/
{31, 0,123,__LINE__, 0xbf847ab4, 0x83367737, 0xbf847ae1, 0x47ae1249},	/* -0.00999967=f(-0.01)*/
{31, 0,123,__LINE__, 0x3cd19000, 0x00000000, 0x3cd19000, 0x00000000},	/* 9.74915e-16=f(9.74915e-16)*/
{31, 0,123,__LINE__, 0x3f847ab4, 0x83367737, 0x3f847ae1, 0x47ae16ad},	/* 0.00999967=f(0.01)*/
{31, 0,123,__LINE__, 0x3f947a2e, 0x5258f3e4, 0x3f947ae1, 0x47ae1594},	/* 0.0199973=f(0.02)*/
{31, 0,123,__LINE__, 0x3f9eb5f6, 0x1cd488c9, 0x3f9eb851, 0xeb851fd2},	/* 0.029991=f(0.03)*/
{31, 0,123,__LINE__, 0x3fa47815, 0xe1479706, 0x3fa47ae1, 0x47ae1508},	/* 0.0399787=f(0.04)*/
{31, 0,123,__LINE__, 0x3fa99424, 0xeb98468a, 0x3fa99999, 0x99999a27},	/* 0.0499584=f(0.05)*/
{31, 0,123,__LINE__, 0x3faeaee5, 0x6e0f2f94, 0x3faeb851, 0xeb851f46},	/* 0.0599281=f(0.06)*/
{31, 0,123,__LINE__, 0x3fb1e40a, 0xaea278b0, 0x3fb1eb85, 0x1eb85232},	/* 0.0698859=f(0.07)*/
{31, 0,123,__LINE__, 0x3fb46fb9, 0x3ff2cfcc, 0x3fb47ae1, 0x47ae14c1},	/* 0.0798298=f(0.08)*/
{31, 0,123,__LINE__, 0x3fb6fa5d, 0xcd496607, 0x3fb70a3d, 0x70a3d750},	/* 0.0897578=f(0.09)*/
{31, 0,123,__LINE__, 0x3fb983d7, 0x7fb56120, 0x3fb99999, 0x999999df},	/* 0.099668=f(0.1)*/
{31, 0,123,__LINE__, 0x3fbc0c06, 0x1c0a9f45, 0x3fbc28f5, 0xc28f5c6e},	/* 0.109558=f(0.11)*/
{31, 0,123,__LINE__, 0x3fbe92c9, 0x8a196039, 0x3fbeb851, 0xeb851efd},	/* 0.119427=f(0.12)*/
{31, 0,123,__LINE__, 0x3fc08c00, 0xfd5c1efe, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.129273=f(0.13)*/
{31, 0,123,__LINE__, 0x3fc1cdc8, 0x06a26fb7, 0x3fc1eb85, 0x1eb8520e},	/* 0.139092=f(0.14)*/
{31, 0,123,__LINE__, 0x3fc30eaa, 0x3ba77e4f, 0x3fc33333, 0x33333356},	/* 0.148885=f(0.15)*/
{31, 0,123,__LINE__, 0x3fc44e98, 0x15459720, 0x3fc47ae1, 0x47ae149e},	/* 0.158649=f(0.16)*/
{31, 0,123,__LINE__, 0x3fc58d82, 0x9a5f30ea, 0x3fc5c28f, 0x5c28f5e6},	/* 0.168381=f(0.17)*/
{31, 0,123,__LINE__, 0x3fc6cb5a, 0xa72d2f46, 0x3fc70a3d, 0x70a3d72e},	/* 0.178081=f(0.18)*/
{31, 0,123,__LINE__, 0x3fc80811, 0x4e22fbfe, 0x3fc851eb, 0x851eb876},	/* 0.187746=f(0.19)*/
{31, 0,123,__LINE__, 0x3fc94398, 0x36da3834, 0x3fc99999, 0x999999be},	/* 0.197375=f(0.2)*/
{31, 0,123,__LINE__, 0x3fca7de0, 0xc8603bef, 0x3fcae147, 0xae147b06},	/* 0.206966=f(0.21)*/
{31, 0,123,__LINE__, 0x3fcbb6dd, 0x221cea59, 0x3fcc28f5, 0xc28f5c4e},	/* 0.216518=f(0.22)*/
{31, 0,123,__LINE__, 0x3fccee7f, 0x47014c81, 0x3fcd70a3, 0xd70a3d96},	/* 0.226028=f(0.23)*/
{30, 0,123,__LINE__, 0x3fce24b9, 0x7c6d2273, 0x3fceb851, 0xeb851ede},	/* 0.235496=f(0.24)*/
{31, 0,123,__LINE__, 0x3fcf597e, 0xa69a1c86, 0x3fd00000, 0x00000013},	/* 0.244919=f(0.25)*/
{31, 0,123,__LINE__, 0x3fd04660, 0xbb75a174, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.254296=f(0.26)*/
{31, 0,123,__LINE__, 0x3fd0df3a, 0xbe6937ae, 0x3fd147ae, 0x147ae15b},	/* 0.263625=f(0.27)*/
{31, 0,123,__LINE__, 0x3fd17746, 0xe02ada59, 0x3fd1eb85, 0x1eb851ff},	/* 0.272905=f(0.28)*/
{31, 0,123,__LINE__, 0x3fd20e7f, 0x241f7d6f, 0x3fd28f5c, 0x28f5c2a3},	/* 0.282135=f(0.29)*/
{31, 0,123,__LINE__, 0x3fd2a4dd, 0xb38fcd80, 0x3fd33333, 0x33333347},	/* 0.291313=f(0.3)*/
{31, 0,123,__LINE__, 0x3fd33a5c, 0x87047be5, 0x3fd3d70a, 0x3d70a3eb},	/* 0.300437=f(0.31)*/
{31, 0,123,__LINE__, 0x3fd3cef6, 0x172ddf0d, 0x3fd47ae1, 0x47ae148f},	/* 0.309507=f(0.32)*/
{31, 0,123,__LINE__, 0x3fd462a5, 0x049fff03, 0x3fd51eb8, 0x51eb8533},	/* 0.318521=f(0.33)*/
{31, 0,123,__LINE__, 0x3fd4f563, 0xc2a61bb5, 0x3fd5c28f, 0x5c28f5d7},	/* 0.327477=f(0.34)*/
{31, 0,123,__LINE__, 0x3fd5872d, 0x44d94d5c, 0x3fd66666, 0x6666667b},	/* 0.336376=f(0.35)*/
{31, 0,123,__LINE__, 0x3fd617fc, 0xa8366b98, 0x3fd70a3d, 0x70a3d71f},	/* 0.345214=f(0.36)*/
{31, 0,123,__LINE__, 0x3fd6a7cc, 0xdf83afa8, 0x3fd7ae14, 0x7ae147c3},	/* 0.353992=f(0.37)*/
{31, 0,123,__LINE__, 0x3fd73699, 0x5d5e8706, 0x3fd851eb, 0x851eb867},	/* 0.362707=f(0.38)*/
{31, 0,123,__LINE__, 0x3fd7c45d, 0xa3330f2c, 0x3fd8f5c2, 0x8f5c290b},	/* 0.37136=f(0.39)*/
{31, 0,123,__LINE__, 0x3fd85115, 0x793c23c1, 0x3fd99999, 0x999999af},	/* 0.379949=f(0.4)*/
{31, 0,123,__LINE__, 0x3fd8dcbc, 0x80f8073c, 0x3fda3d70, 0xa3d70a53},	/* 0.388473=f(0.41)*/
{31, 0,123,__LINE__, 0x3fd9674e, 0xda335a52, 0x3fdae147, 0xae147af7},	/* 0.39693=f(0.42)*/
{31, 0,123,__LINE__, 0x3fd9f0c8, 0xcfb771c0, 0x3fdb851e, 0xb851eb9b},	/* 0.405321=f(0.43)*/
{31, 0,123,__LINE__, 0x3fda7926, 0x87b830fc, 0x3fdc28f5, 0xc28f5c3f},	/* 0.413644=f(0.44)*/
{31, 0,123,__LINE__, 0x3fdb0064, 0xa4eb581e, 0x3fdccccc, 0xcccccce3},	/* 0.421899=f(0.45)*/
{31, 0,123,__LINE__, 0x3fdb867f, 0xf4ed5088, 0x3fdd70a3, 0xd70a3d87},	/* 0.430084=f(0.46)*/
{31, 0,123,__LINE__, 0x3fdc0b75, 0x228cc44a, 0x3fde147a, 0xe147ae2b},	/* 0.438199=f(0.47)*/
{31, 0,123,__LINE__, 0x3fdc8f41, 0x52ca7782, 0x3fdeb851, 0xeb851ecf},	/* 0.446244=f(0.48)*/
{31, 0,123,__LINE__, 0x3fdd11e1, 0xd50bdfa6, 0x3fdf5c28, 0xf5c28f73},	/* 0.454216=f(0.49)*/
{31, 0,123,__LINE__, 0x3fdd9353, 0xd7568af3, 0x3fe00000, 0x0000000b},	/* 0.462117=f(0.5)*/
{31, 0,123,__LINE__, 0x3fde1394, 0xff1a989d, 0x3fe051eb, 0x851eb85d},	/* 0.469945=f(0.51)*/
{31, 0,123,__LINE__, 0x3fde92a3, 0x029587f5, 0x3fe0a3d7, 0x0a3d70af},	/* 0.4777=f(0.52)*/
{31, 0,123,__LINE__, 0x3fdf107b, 0xc21445fd, 0x3fe0f5c2, 0x8f5c2901},	/* 0.485381=f(0.53)*/
{31, 0,123,__LINE__, 0x3fdf8d1d, 0x77fd0a49, 0x3fe147ae, 0x147ae153},	/* 0.492988=f(0.54)*/
{31, 0,123,__LINE__, 0x3fe00442, 0xfb0d8481, 0x3fe19999, 0x999999a5},	/* 0.50052=f(0.55)*/
{31, 0,123,__LINE__, 0x3fe04159, 0xe4a0014b, 0x3fe1eb85, 0x1eb851f7},	/* 0.507977=f(0.56)*/
{31, 0,123,__LINE__, 0x3fe07dd2, 0xbac5797e, 0x3fe23d70, 0xa3d70a49},	/* 0.515359=f(0.57)*/
{31, 0,123,__LINE__, 0x3fe0b9ac, 0xd364dc1d, 0x3fe28f5c, 0x28f5c29b},	/* 0.522665=f(0.58)*/
{31, 0,123,__LINE__, 0x3fe0f4e7, 0x97f39ce5, 0x3fe2e147, 0xae147aed},	/* 0.529896=f(0.59)*/
{31, 0,123,__LINE__, 0x3fe12f82, 0x9bee7fab, 0x3fe33333, 0x3333333f},	/* 0.53705=f(0.6)*/
{31, 0,123,__LINE__, 0x3fe1697d, 0x413629fe, 0x3fe3851e, 0xb851eb91},	/* 0.544127=f(0.61)*/
{31, 0,123,__LINE__, 0x3fe1a2d7, 0x4117ab46, 0x3fe3d70a, 0x3d70a3e3},	/* 0.551128=f(0.62)*/
{31, 0,123,__LINE__, 0x3fe1db90, 0x5025fabc, 0x3fe428f5, 0xc28f5c35},	/* 0.558052=f(0.63)*/
{31, 0,123,__LINE__, 0x3fe213a8, 0x34e54dfe, 0x3fe47ae1, 0x47ae1487},	/* 0.5649=f(0.64)*/
{31, 0,123,__LINE__, 0x3fe24b1e, 0xc7703122, 0x3fe4cccc, 0xccccccd9},	/* 0.57167=f(0.65)*/
{31, 0,123,__LINE__, 0x3fe281f4, 0x066618da, 0x3fe51eb8, 0x51eb852b},	/* 0.578363=f(0.66)*/
{31, 0,123,__LINE__, 0x3fe2b827, 0xc11e21e8, 0x3fe570a3, 0xd70a3d7d},	/* 0.58498=f(0.67)*/
{31, 0,123,__LINE__, 0x3fe2edba, 0x17c99e36, 0x3fe5c28f, 0x5c28f5cf},	/* 0.591519=f(0.68)*/
{31, 0,123,__LINE__, 0x3fe322ab, 0x252528fc, 0x3fe6147a, 0xe147ae21},	/* 0.597982=f(0.69)*/
{31, 0,123,__LINE__, 0x3fe356fb, 0x139f397c, 0x3fe66666, 0x66666673},	/* 0.604368=f(0.7)*/
{31, 0,123,__LINE__, 0x3fe38aaa, 0x1cf2a06c, 0x3fe6b851, 0xeb851ec5},	/* 0.610677=f(0.71)*/
{31, 0,123,__LINE__, 0x3fe3bdb8, 0x9d923c1f, 0x3fe70a3d, 0x70a3d717},	/* 0.616909=f(0.72)*/
{31, 0,123,__LINE__, 0x3fe3f026, 0xc4b9a929, 0x3fe75c28, 0xf5c28f69},	/* 0.623065=f(0.73)*/
{31, 0,123,__LINE__, 0x3fe421f5, 0x0bae9fa4, 0x3fe7ae14, 0x7ae147bb},	/* 0.629145=f(0.74)*/
{31, 0,123,__LINE__, 0x3fe45323, 0xe552f228, 0x3fe80000, 0x0000000d},	/* 0.635149=f(0.75)*/
{31, 0,123,__LINE__, 0x3fe483b3, 0xd1cc4882, 0x3fe851eb, 0x851eb85f},	/* 0.641077=f(0.76)*/
{31, 0,123,__LINE__, 0x3fe4b3a5, 0x5e1a9c8e, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.646929=f(0.77)*/
{31, 0,123,__LINE__, 0x3fe4e2f9, 0x23ae9d67, 0x3fe8f5c2, 0x8f5c2903},	/* 0.652707=f(0.78)*/
{31, 0,123,__LINE__, 0x3fe511af, 0xda20de09, 0x3fe947ae, 0x147ae155},	/* 0.658409=f(0.79)*/
{31, 0,123,__LINE__, 0x3fe53fca, 0x0e087efc, 0x3fe99999, 0x999999a7},	/* 0.664037=f(0.8)*/
{31, 0,123,__LINE__, 0x3fe56d48, 0x8e0dd01d, 0x3fe9eb85, 0x1eb851f9},	/* 0.66959=f(0.81)*/
{31, 0,123,__LINE__, 0x3fe59a2c, 0x21473e1c, 0x3fea3d70, 0xa3d70a4b},	/* 0.67507=f(0.82)*/
{31, 0,123,__LINE__, 0x3fe5c675, 0x992f4a62, 0x3fea8f5c, 0x28f5c29d},	/* 0.680476=f(0.83)*/
{31, 0,123,__LINE__, 0x3fe5f225, 0xd13d35cf, 0x3feae147, 0xae147aef},	/* 0.685809=f(0.84)*/
{31, 0,123,__LINE__, 0x3fe61d3d, 0xbf3629d9, 0x3feb3333, 0x33333341},	/* 0.691069=f(0.85)*/
{31, 0,123,__LINE__, 0x3fe647be, 0x2fade1c2, 0x3feb851e, 0xb851eb93},	/* 0.696258=f(0.86)*/
{31, 0,123,__LINE__, 0x3fe671a8, 0x2aa1777d, 0x3febd70a, 0x3d70a3e5},	/* 0.701374=f(0.87)*/
{31, 0,123,__LINE__, 0x3fe69afc, 0xaf837b0b, 0x3fec28f5, 0xc28f5c37},	/* 0.706419=f(0.88)*/
{31, 0,123,__LINE__, 0x3fe6c3bc, 0xc5cca797, 0x3fec7ae1, 0x47ae1489},	/* 0.711394=f(0.89)*/
{31, 0,123,__LINE__, 0x3fe6ebe9, 0x7c9ad878, 0x3feccccc, 0xccccccdb},	/* 0.716298=f(0.9)*/
{31, 0,123,__LINE__, 0x3fe71383, 0xf9ad3df6, 0x3fed1eb8, 0x51eb852d},	/* 0.721132=f(0.91)*/
{31, 0,123,__LINE__, 0x3fe73a8d, 0x3b5e00f0, 0x3fed70a3, 0xd70a3d7f},	/* 0.725897=f(0.92)*/
{31, 0,123,__LINE__, 0x3fe76106, 0x7516c86a, 0x3fedc28f, 0x5c28f5d1},	/* 0.730594=f(0.93)*/
{31, 0,123,__LINE__, 0x3fe786f0, 0xd0db87fb, 0x3fee147a, 0xe147ae23},	/* 0.735222=f(0.94)*/
{31, 0,123,__LINE__, 0x3fe7ac4d, 0x7e85af15, 0x3fee6666, 0x66666675},	/* 0.739783=f(0.95)*/
{31, 0,123,__LINE__, 0x3fe7d11d, 0xb36c2b33, 0x3feeb851, 0xeb851ec7},	/* 0.744277=f(0.96)*/
{31, 0,123,__LINE__, 0x3fe7f562, 0xb81d047d, 0x3fef0a3d, 0x70a3d719},	/* 0.748704=f(0.97)*/
{31, 0,123,__LINE__, 0x3fe8191d, 0xaf938402, 0x3fef5c28, 0xf5c28f6b},	/* 0.753066=f(0.98)*/
{31, 0,123,__LINE__, 0x3fe83c4f, 0xebe655c0, 0x3fefae14, 0x7ae147bd},	/* 0.757362=f(0.99)*/
{31, 0,123,__LINE__, 0x3fe85efa, 0xb514f394, 0x3ff00000, 0x00000007},	/* 0.761594=f(1)*/
{31, 0,123,__LINE__, 0x3fe8811f, 0x56fe8c0b, 0x3ff028f5, 0xc28f5c30},	/* 0.765762=f(1.01)*/
{31, 0,123,__LINE__, 0x3fe8a2bf, 0x2114b4c9, 0x3ff051eb, 0x851eb859},	/* 0.769867=f(1.02)*/
{31, 0,123,__LINE__, 0x3fe8c3db, 0x660ffc0e, 0x3ff07ae1, 0x47ae1482},	/* 0.773908=f(1.03)*/
{31, 0,123,__LINE__, 0x3fe8e475, 0x7ba65d2e, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.777888=f(1.04)*/
{31, 0,123,__LINE__, 0x3fe9048e, 0xba439aea, 0x3ff0cccc, 0xccccccd4},	/* 0.781806=f(1.05)*/
{31, 0,123,__LINE__, 0x3fe92428, 0x7cc381b4, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.785664=f(1.06)*/
{31, 0,123,__LINE__, 0x3fe94344, 0x384ac334, 0x3ff11eb8, 0x51eb8526},	/* 0.789461=f(1.07)*/
{31, 0,123,__LINE__, 0x3fe961e3, 0x1b315dd8, 0x3ff147ae, 0x147ae14f},	/* 0.793199=f(1.08)*/
{31, 0,123,__LINE__, 0x3fe98006, 0x9e929588, 0x3ff170a3, 0xd70a3d78},	/* 0.796878=f(1.09)*/
{31, 0,123,__LINE__, 0x3fe99db0, 0x24772beb, 0x3ff19999, 0x999999a1},	/* 0.800499=f(1.1)*/
{31, 0,123,__LINE__, 0x3fe9bae1, 0x1017dbf4, 0x3ff1c28f, 0x5c28f5ca},	/* 0.804062=f(1.11)*/
{31, 0,123,__LINE__, 0x3fe9d79a, 0xc5a3097f, 0x3ff1eb85, 0x1eb851f3},	/* 0.807569=f(1.12)*/
{31, 0,123,__LINE__, 0x3fe9f3de, 0xaa045182, 0x3ff2147a, 0xe147ae1c},	/* 0.811019=f(1.13)*/
{31, 0,123,__LINE__, 0x3fea0fae, 0x22adf735, 0x3ff23d70, 0xa3d70a45},	/* 0.814414=f(1.14)*/
{31, 0,123,__LINE__, 0x3fea2b0a, 0x956429fb, 0x3ff26666, 0x6666666e},	/* 0.817754=f(1.15)*/
{31, 0,123,__LINE__, 0x3fea45f5, 0x680a1f66, 0x3ff28f5c, 0x28f5c297},	/* 0.82104=f(1.16)*/
{31, 0,123,__LINE__, 0x3fea6070, 0x0070fc32, 0x3ff2b851, 0xeb851ec0},	/* 0.824272=f(1.17)*/
{31, 0,123,__LINE__, 0x3fea7a7b, 0xc428869f, 0x3ff2e147, 0xae147ae9},	/* 0.827452=f(1.18)*/
{31, 0,123,__LINE__, 0x3fea941a, 0x2c2aec65, 0x3ff30a3d, 0x70a3d712},	/* 0.830579=f(1.19)*/
{31, 0,123,__LINE__, 0xbfeffff1, 0x5f824f7b, 0xc01921fb, 0x54442d18},	/* -0.999993=f(-6.28319)*/
{31, 0,123,__LINE__, 0xbfeffead, 0x8c8c0588, 0xc012d97c, 0x7f3321d2},	/* -0.999839=f(-4.71239)*/
{31, 0,123,__LINE__, 0xbfefe175, 0xfa8292df, 0xc00921fb, 0x54442d18},	/* -0.996272=f(-3.14159)*/
{31, 0,123,__LINE__, 0xbfed594f, 0xde9eb701, 0xbff921fb, 0x54442d18},	/* -0.917152=f(-1.5708)*/
{31, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},	/* 0=f(0)*/
{31, 0,123,__LINE__, 0x3fed594f, 0xde9eb701, 0x3ff921fb, 0x54442d18},	/* 0.917152=f(1.5708)*/
{31, 0,123,__LINE__, 0x3fefe175, 0xfa8292df, 0x400921fb, 0x54442d18},	/* 0.996272=f(3.14159)*/
{31, 0,123,__LINE__, 0x3feffead, 0x8c8c0588, 0x4012d97c, 0x7f3321d2},	/* 0.999839=f(4.71239)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc03e0000, 0x00000000},	/* -1=f(-30)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc03c4ccc, 0xcccccccd},	/* -1=f(-28.3)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc03a9999, 0x9999999a},	/* -1=f(-26.6)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc038e666, 0x66666667},	/* -1=f(-24.9)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc0373333, 0x33333334},	/* -1=f(-23.2)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc0358000, 0x00000001},	/* -1=f(-21.5)*/
{31, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xc033cccc, 0xccccccce},	/* -1=f(-19.8)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xfffffffd, 0xc0321999, 0x9999999b},	/* -1=f(-18.1)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xffffff99, 0xc0306666, 0x66666668},	/* -1=f(-16.4)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xfffff400, 0xc02d6666, 0x6666666a},	/* -1=f(-14.7)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xfffe987b, 0xc02a0000, 0x00000004},	/* -1=f(-13)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xffd5eb4e, 0xc0269999, 0x9999999e},	/* -1=f(-11.3)*/
{31, 0,123,__LINE__, 0xbfefffff, 0xfb131607, 0xc0233333, 0x33333338},	/* -1=f(-9.6)*/
{31, 0,123,__LINE__, 0xbfefffff, 0x6c69d4e8, 0xc01f9999, 0x999999a3},	/* -1=f(-7.9)*/
{31, 0,123,__LINE__, 0xbfefffee, 0xb9b72ff4, 0xc018cccc, 0xccccccd6},	/* -0.999992=f(-6.2)*/
{31, 0,123,__LINE__, 0xbfeffdfa, 0x72153983, 0xc0120000, 0x00000009},	/* -0.999753=f(-4.5)*/
{31, 0,123,__LINE__, 0xbfefc3a3, 0x2d278a05, 0xc0066666, 0x66666678},	/* -0.992632=f(-2.8)*/
{31, 0,123,__LINE__, 0xbfe99db0, 0x24772beb, 0xbff19999, 0x999999bd},	/* -0.800499=f(-1.1)*/
{31, 0,123,__LINE__, 0x3fe12f82, 0x9bee7fab, 0x3fe33333, 0x333332ec},	/* 0.53705=f(0.6)*/
{31, 0,123,__LINE__, 0x3fef5cf3, 0x1d1a383b, 0x40026666, 0x66666654},	/* 0.980096=f(2.3)*/
{31, 0,123,__LINE__, 0x3feffa81, 0x708a0b42, 0x400fffff, 0xffffffee},	/* 0.999329=f(4)*/
{31, 0,123,__LINE__, 0x3fefffd1, 0x0b11d67d, 0x4016cccc, 0xccccccc4},	/* 0.999978=f(5.7)*/
{31, 0,123,__LINE__, 0x3feffffe, 0x6ed17151, 0x401d9999, 0x99999991},	/* 0.999999=f(7.4)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xf29c7b05, 0x40223333, 0x3333332f},	/* 1=f(9.1)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xff8d9cc8, 0x40259999, 0x99999995},	/* 1=f(10.8)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xfffc2eb9, 0x4028ffff, 0xfffffffb},	/* 1=f(12.5)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xffffdf63, 0x402c6666, 0x66666661},	/* 1=f(14.2)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xfffffee9, 0x402fcccc, 0xccccccc7},	/* 1=f(15.9)*/
{31, 0,123,__LINE__, 0x3fefffff, 0xfffffff7, 0x40319999, 0x99999997},	/* 1=f(17.6)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x40334ccc, 0xccccccca},	/* 1=f(19.3)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x4034ffff, 0xfffffffd},	/* 1=f(21)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x4036b333, 0x33333330},	/* 1=f(22.7)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x40386666, 0x66666663},	/* 1=f(24.4)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403a1999, 0x99999996},	/* 1=f(26.1)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 1=f(27.8)*/
{31, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 1=f(29.5)*/
{0},};
void test_tanhf(int m)   {run_vector_1(m,tanhf_vec,(char *)(tanhf),"tanhf","ff");   }
